@@ -1,5 +1,5 @@
 from concurrent.futures import ThreadPoolExecutor
-from utils.singleton_wrapper import Singleton
+from hamunafs.utils.singleton_wrapper import Singleton
 import requests
 import shutil
 import traceback
