@@ -447,6 +447,9 @@ class Client(Singleton):
                             return await self.get_from_cloud_async(path, tmp_url, force_copy, min_size)
                     
                     await asyncio.sleep(1/30)
+                return False, '超时'
+            else:
+                return False, 'MQ发送失败'
         except Exception as e:
             return False, '获取失败'
     
