@@ -138,11 +138,10 @@ class MQManager(Singleton):
                 
             resp = await mq.pub(topic, message)
             return resp.is_ok
-        except ConnectionClosedError as e:
-            await self.close_async()
-            return await self.__mq_pub(topic, message, None, tries+1)
         except:
             traceback.print_exc()
+            await self.close_async()
+            return await self.__mq_pub(topic, message, None, tries+1)
 
 
     async def async_publish(self, topic, message, mq=None):
@@ -153,9 +152,12 @@ class MQManager(Singleton):
                 pass
             else:
                 message = orjson.dumps(message)
-            print('publishing')
 
             ret = await self.__mq_pub(topic, message)
+            if ret:
+                print('published')
+            else:
+                print('publish failed')
             return ret
         except Exception as e:
             print(traceback.print_exc())
